import argparse
import sys

def calculate(args):
    if args.o == 'add':
        return args.x + args.y
    if args.o == 'sub':
        return args.x - args.y
    if args.o == 'mul':
        return args.x * args.y
    if args.o == 'div':  # Corrected 'add' to 'div' for the last condition
        return args.x / args.y

def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('--x', type=float, default=1.0, help="Contact Salman")
    parser.add_argument('--y', type=float, default=2.0, help="Contact Salman")
    parser.add_argument('--o', type=str, default="add", help="Contact Salman")
    args = parser.parse_args()
    sys.stdout.write(str(calculate(args)))

if __name__ == "__main__":
    main()






import argparse
import sys

def calculate(args):

    if args.o == 'add' :
        return args.x + args.y
    
    if args.o == 'sub' :
        return args.x - args.y
    
    if args.o == 'mul' :
        return args.x * args.y
    
    if args.o == 'add' :
        return args.x // args.y


if __name__ == '__main__':

    parser = argparse.ArgumentParser()

    parser.add_argument('--x' , type = float , default = 1.0 , help = "Conatct Salman")

    parser.add_argument('--y' , type = float , default = 2.0 , help = "Conatct Salman")

    parser.add_argument('--o' , type = str , default = "add" , help = "Conatct Salman")

    args = parser.parse_args()

    sys.stdout.write(str(calculate(args)))
    sys.stdout.write(str(calculate("")))
    








import setuptools


with open("README.md", "r") as fh:
    long_description = fh.read()


setuptools.setup(
    name='argscalculator',
    version='0.0.1',
    description='Django project initialize',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Salman Latif",
    author_email="salu33956@gmail.com",
    py_modules=['argscalculator'],
    include_package_data=True,
    package_dir={'': 'src'},
    packages = setuptools.find_packages(where="src"),
    python_requires = ">=3.6",
    install_requires=[
        'Django>=3.8',
        'virtualenv>=20'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    entry_points={
        'console_scripts': ['argscalculator=argscalculator.index:main']
    },
)